@@ -32,6 +32,6 @@ ax.set_xlim(0, 5)
 ax.set_ylim(-0.5, 1.0)
 
 ax.set_xlabel('redshift')
-ax.set_ylabel('r-i color')
+ax.set_ylabel('r-i')
 
 plt.show()
